OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Pedido falhou, ligação à rede indisponível!",
    "Request unauthorized. Are you logged in?" : "Pedido não autorizado. Fez o login?",
    "Request forbidden. Are you an admin?" : "Pedido proibido. É um administrador?",
    "Token expired or app not enabled! Reload the page!" : "Token expirou ou aplicação não ativa! Recarregue a página!",
    "Can not add feed: Exists already" : "Não é possível adicionar o feed: Já existe",
    "Articles without feed" : "Artigos sem feed",
    "Can not add folder: Exists already" : "Não é possível adicionar a pasta: Já existe",
    "Disable this if you run a custom updater such as the Python updater included in the app" : "Desative isto se estiver a utilizar um atualizador personalizado, tal como, o atualizador Python incluído na app",
    "Purge interval" : "Intervalo de Purgar",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Número mínimo de segundos depois de remover os feeds e as pastas da base de dados; os valores abaixo de 60 segundos são ignorados",
    "Maximum read count per feed" : "Número máximo de leituras por feed",
    "Maximum redirects" : "Máximo de redirecionamentos",
    "How many redirects the feed fetcher should follow" : "Quantos redirecionamentos é que o 'obter feed' deverá seguir",
    "Maximum feed page size" : "Tamanho máximo da página feed",
    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Tamanho máximo da feed em bytes. Se a página RSS/Atom for maior do que este valor, a atualização será abortada",
    "Feed fetcher timeout" : "A obtenção do feed expirou",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Número máximo de segundos a esperar por feed RSS ou Atom para carregar; se demorar desmasiado, a actualização será cancelada",
    "Explore Service URL" : "Explorar Serviço URL",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Se autorizado, este serviço URL será consultado para mostrar os feeds na secção de exploração de feeds. Para voltar ao serviço de exploração anterior, deixe isto vazio",
    "Saved" : "Guardado",
    "Download" : "Transferir",
    "Close" : "Fechar",
    "filter" : "filtro",
    "Language" : "Idioma",
    "Subscribe" : "Subscrever",
    "Got more awesome feeds? Share them with us!" : "Tens mais feedback fantástico? Partilha-o connosco!",
    "No articles available" : "Não há artigos disponíveis",
    "No unread articles available" : "Não há artigos por ler disponíveis",
    "Open website" : "Abrir site da web",
    "Star article" : "Destacar artigo",
    "Unstar article" : "Retirar destaque",
    "Keep article unread" : "Marcar artigo como não lido",
    "Remove keep article unread" : "Remover marcação de artigo não lido",
    "by" : "por",
    "from" : "de",
    "Play audio" : "Reproduzir áudio",
    "Download audio" : "Transferir áudio",
    "Download video" : "Transferir vídeo",
    "Keyboard shortcut" : "Atalho de teclado",
    "Description" : "Descrição",
    "right" : "direita",
    "Jump to next article" : "Ir para o artigo seguinte",
    "left" : "esquerda",
    "Jump to previous article" : "Ir para o artigo anterior",
    "Toggle star article" : "Alternar estrela do artigo",
    "Star article and jump to next one" : "Destacar artigo e saltar para o próximo",
    "Toggle keep current article unread" : "Alternar manter o artigo atual como não lido",
    "Open article in new tab" : "Abrir artigo num separador novo",
    "Toggle expand article in compact view" : "Alternar expandir artigo na visulaização compacta",
    "Refresh" : "Atualizar",
    "Load next feed" : "Carregar feed seguinte",
    "Load previous feed" : "Carregar feed anterior",
    "Load next folder" : "Carregar pasta seguinte",
    "Load previous folder" : "Carregar pasta anterior",
    "Scroll to active navigation entry" : "Vá até a entrada de navegação ativa",
    "Focus search field" : "Focar campo de pesquisa",
    "Mark current article's feed/folder read" : "Marcar a pasta/feed do artigo atual como lida",
    "How to set up the operating system cron" : "Como configurar o cron no sistema operativo",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instale e configure um actualizador paralelo mais rápido que use a API de actualizações da aplicação Notícias",
    "Web address" : "Endereço da Web",
    "Feed exists already!" : "A feed já existe!",
    "Folder" : "Pasta",
    "No folder" : "Sem Pasta",
    "New folder" : "Nova Pasta",
    "Folder name" : "Nome da pasta",
    "Go back" : "Voltar",
    "Folder exists already!" : "A pasta já existe!",
    "Credentials" : "Credenciais",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "As credenciais de autenticação básica HTTP têm de ser armazenadas de forma não encriptada. Qualquer pessoa com acesso ao servidor ou base de dados poderá vê-las!",
    "Username" : "Nome de utilizador",
    "Password" : "Senha",
    "New Folder" : "Nova Pasta",
    "Create" : "Criar",
    "Explore" : "Explorar",
    "Update failed more than 50 times" : "A atualização falhou mais de 50 vezes",
    "Deleted feed" : "Apagar feed",
    "Undo delete feed" : "Desfazer apagar a feed",
    "Rename" : "Renomear",
    "Menu" : "Menu",
    "Mark read" : "Marcar como lido",
    "Newest first" : "Recentes primeiro",
    "Oldest first" : "Antigos primeiro",
    "Delete" : "Apagar",
    "Dismiss" : "Rejeitar",
    "Collapse" : "Expandir",
    "Deleted folder" : "Apagar pasta",
    "Undo delete folder" : "Anular apagar pasta",
    "Starred" : "Marcado",
    "Unread articles" : "Artigos não lidos",
    "All articles" : "Todos os artigos",
    "Settings" : "Definições",
    "Disable mark read through scrolling" : "Desativar marcar ler através de movimento",
    "Compact view" : "Visualização Compacta",
    "Expand articles on key navigation" : "Expandir artigos ao navegar por tecla",
    "Show all articles" : "Mostrar todos os artigos",
    "Reverse ordering (oldest on top)" : "Ordem inversa (antigos no topo)",
    "Subscriptions (OPML)" : "Subscrições (OPML)",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Erro na importção: OPML não contém nem feeds nem pastas",
    "Unread/Starred Articles" : "Artigos Não Lidos/Classificados",
    "Error when importing: file does not contain valid JSON" : "Ocorreu um erro na importação: o ficheiro não contém JSON válido",
    "Help" : "Ajuda",
    "Keyboard shortcuts" : "Atalhos de teclado",
    "Documentation" : "Documentação",
    "Report a bug" : "Reportar um erro"
},
"nplurals=2; plural=(n != 1);");
